@@ -1,6 +1,6 @@
 from pathlib import Path
 
-VERSION = '0.0.38'
+VERSION = '0.0.39'
 CLI_NAME = 'figgy'
 PROJECT_NAME = 'figgy'
 
@@ -13,6 +13,10 @@ FIGGY_ERROR_REPORTING_URL = f"{FIGGY_OBS_API_BASE_URL}/v1/log-error"
 FIGGY_GET_VERSION_URL = f"{FIGGY_OBS_API_BASE_URL}/v1/version"
 FIGGY_LOG_METRICS_URL = f"{FIGGY_OBS_API_BASE_URL}/v1/log-metrics"
 
+# DOCS URLS
+DOCS_URL = 'https://www.figgy.dev/docs'
+INSTALL_URL = f'{DOCS_URL}/getting-started/install/'
+
 # Homebrew
 BREW_FORMULA = 'figtools/figgy/figgy'
 
